@@ -10,7 +10,7 @@ import shutil
 
 from loguru import logger
 from pywebio.input import input, FLOAT,NUMBER,input_group,select, textarea,file_upload,checkbox,radio,actions
-from pywebio.output import close_popup, output, put_file, put_html, put_image, put_markdown, put_text,popup,put_link,put_code,put_row,put_processbar,set_processbar,put_error,put_warning,toast,put_grid,put_button,put_table,use_scope,span,clear,remove
+from pywebio.output import popup, close_popup, output, put_file, put_html, put_image, put_markdown, put_text,popup,put_link,put_code,put_row,put_processbar,set_processbar,put_error,put_warning,toast,put_grid,put_button,put_table,use_scope,span,clear,remove
 from pywebio import start_server,session,platform
 from core.bladeTest.main import RemoteRunner,generateHtmlReport,running
 from core.jmeterTool.swagger2jmeter import swagger2jmeter
@@ -147,7 +147,7 @@ def onePageInput():
         put_code(json_str, language='json') 
         runAndGetReport(json.loads(json_str))
     except Exception as e:
-        toast(e)
+        popup(title="error",content=put_text(e))
         clear('content')
 
 
@@ -255,7 +255,7 @@ def oneCheck():
                 runAndGetReport(input_data)
                 
     except Exception as e:
-        toast(e)
+        popup(title="error",content=put_text(e))
         clear('content')
 
             
