@@ -14,9 +14,73 @@ from xml.dom.minidom import parse
 import xmltodict
 from jsonpath import jsonpath
 import wget
+import traceback
+
+
+def mkdirAfterCheck(path):
+    if not os.path.exists(path):
+        os.mkdir(path)
+    
+def mkfileAfterCheck(path,fileName):
+    mkdirAfterCheck(path)
+    if not os.path.exists(path+os.sep+fileName):
+        open(path+os.sep+fileName,'w',encoding='utf-8')
+            
+    
+
+
+def timeit(func):
+    '''
+        func：funtion name which need calculate time
+    '''
+    @wraps(func)
+    def calculate(*args,**kwargs):
+        start=datetime.now()
+        func(*args,**kwargs)
+        end=datetime.now()
+        logger.info(f"{func.__name__} costs {(end-start).seconds}")
+        return calculate
+
+
+def addException(func):
+    @wraps(func)
+    def innerFun(*args,**kwargs):
+        try:
+            res=None
+            res=func(*args,**kwargs)
+        except Exception as e:
+            print(e)
+            print('Exception found, detail below:')
+            print(traceback.format_exc())
+        return res
+    return innerFun
+
+
+def singleton(cls):
+    instance = {}
+    @wraps(cls)
+    def get_insance(*args, **kwargs):
+        if cls not in instance:
+            instance[cls] = cls(*args, **kwargs)
+        return instance[cls]
+    return get_insance
 
 
 
+def jsonPrettyOutput(json_string):
+    try:
+        parsed_json = json.loads(json_string)
+        formatted_json = json.dumps(parsed_json, indent = 4,sort_keys=True)
+        return formatted_json
+    except Exception as e:
+        return e
+
+
+
+
+
+
+@addException
 def email_sender(host="smtp.163.com",sender="xxx@163.com",auth_code='xxx',reciever=['xxx','xxx'],content="email content"):
     import smtplib
     import email
@@ -70,6 +134,48 @@ def download2Dest(url,destDir,fileName):
     return True
 
 
+class strFilter(object):
+    def __init__(self,oriStr,targetStr,flag="",pattern="",retFlag="yes"):
+        self.oriStr=oriStr
+        self.targetStr=targetStr
+        self.flag=flag
+        self.pattern=pattern
+        self.retFlag=retFlag
+    def falgValidate(self):
+        if flag=="":
+            self.filterContain()
+        elif flag=="json":
+            self.filterJson()
+        elif flag=="regx":
+            self.filterRegx()
+        else:
+            logger.error('your choose wrong flter flag')
+    def filterContain(self):
+        if self.retFlag.lower()=="no":
+            if self.targetStr in self.oriStr:
+                return True
+            else:
+                return False
+        else:
+            if self.targetStr in self.oriStr:
+                return self.oriStr
+            else:
+                return None
+    def filterJson(self):
+        if self.retFlag.lower()=="no":
+            if self.targetStr in self.oriStr:
+                return True
+            else:
+                return False
+        else:
+            if self.targetStr in self.oriStr:
+                return self.oriStr
+            else:
+                return None
+
+
+
+
 def findBy(oriStr,flag="",pattern=""):
     if flag=="json":
         if isJson(str(oriStr)):
@@ -211,28 +317,6 @@ def getDimons(mylist):
     return num
 
 
-def timeit(func):
-    '''
-        func：funtion name which need calculate time
-    '''
-    @wraps(func)
-    def calculate(*args,**kwargs):
-        start=datetime.now()
-        func(*args,**kwargs)
-        end=datetime.now()
-        logger.info(f"{func.__name__} costs {(end-start).seconds}")
-        return calculate
-
-def singleton(cls):
-    instance = {}
-
-    @wraps(cls)
-    def get_insance(*args, **kwargs):
-        if cls not in instance:
-            instance[cls] = cls(*args, **kwargs)
-        return instance[cls]
-
-    return get_insance
 
 dbInfo={}
 class mysql_exe(object):
@@ -285,7 +369,7 @@ class mysql_exe(object):
         self.conn.close()
 
 
-
+@addException
 def getSha1Password(passwdStr,key="terminus2021"):
     '''
 
@@ -296,7 +380,7 @@ def getSha1Password(passwdStr,key="terminus2021"):
     sh=hashlib.sha1(bytes(key+passwdStr,encoding='utf-8')).hexdigest()
     return sh
 
-
+@addException
 def getData(keyStr,businessData):
     '''
 
@@ -492,7 +576,9 @@ def timeStampStr2FormatTime(timestamp: int, format_style='%Y-%m-%d %H:%M:%S.%f')
     # return time.strftime(format_type,time.localtime(timestampStr))
 
     timestamp = float(timestamp) / 1000
-    ret_datetime = datetime.utcfromtimestamp(timestamp).strftime(format_style)
+    # ret_datetime = datetime.utcfromtimestamp(timestamp).strftime(format_style)
+    ret_datetime = datetime.fromtimestamp(timestamp).strftime(format_style)
+    # datetime.fromtimestamp(t)
     return ret_datetime
 
 
@@ -512,7 +598,14 @@ def timestampsCompare(bigOne: int, smarllOne: int):
     return dalta.total_seconds()
 
 
-
+def timeComparedBySeconds(starter,ender):
+    '''
+    #starter=datetime.now()
+    #time.sleep(3)
+    #ender=datetime.now()
+    '''
+    num=(ender-starter).seconds
+    return num
 
 
 def getDateTime(format="%Y-%m-%d %H:%M:%S.%f"):
@@ -668,10 +761,9 @@ def parseJmeterXml(filePath='/Users/oupeng/ssoHttp.jmx'):
     # return paramList
 
 
-
 if __name__=='__main__':
     # print(CFacker().get_it("month"))
-    # print(swagger2jmeter("http://192.168.118.168:12812/space/v2/api-docs"))
+    # print(swagger2jmeter("http://192.168.xxx.xxx:123456/space/v2/api-docs"))
     # print(formatStr2Timestamp("2022-04-01 08:08:08.345"))
     # print(timeStampStr2FormatTime(1648741273123))
     # timestampsCompare(1648741273123, 1648741259023)
